scopus
======

Access Elsevier Scopus's API from Python on a large scale.

Documentation: https://scopus.readthedocs.io

Development: https://github.com/scopus-api/scopus

.. image:: https://badge.fury.io/py/scopus.svg
    :target: https://badge.fury.io/py/scopus

.. image:: https://img.shields.io/pypi/pyversions/scopus.svg
    :target: https://img.shields.io/pypi/pyversions/scopus.svg

.. image:: https://readthedocs.org/projects/scopus/badge/?version=latest
    :target: https://readthedocs.org/projects/scopus/badge/?version=latest

.. image:: https://img.shields.io/pypi/dm/scopus.svg
    :target: https://img.shields.io/pypi/dm/scopus.svg

.. image:: https://img.shields.io/pypi/l/scopus.svg
    :target: https://img.shields.io/pypi/l/scopus.svg

.. image:: https://api.codeclimate.com/v1/badges/047a5aceea97e601e924/maintainability
   :target: https://codeclimate.com/github/scopus-api/scopus/maintainability

Installation
============

Install stable version from PyPI:

.. code:: bash

    pip install scopus

or development version from GitHub repository:

.. code:: bash

    pip install git+git://github.com/scopus-api/scopus

Citation
========
If scopus helped you getting data for research, please cite our corresponding paper:

* Rose, Michael E. and John R. Kitchin (2019): "`scopus: Scriptable bibliometrics using a Python interface to Scopus <./meta/RoseJohn2019_scopus.pdf>`_", Max Planck Institute for Innovation and Competition Research Paper No. 19-03.

Citing the paper helps the development of scopus, because it justifies funneling resources into the development.

Change log
==========

Please see `CHANGES.rst <./meta/CHANGES.rst>`_.

Contributing
============

Please see `CONTRIBUTING.rst <CONTRIBUTING.rst>`_. For a list of contributors see
`AUTHORS.rst <./meta/AUTHORS.rst>`_.

License
=======

MIT License; see `LICENSE <LICENSE>`_.
